/*
 * Copyright (c) 2013 by Piero Orsoni (www.opbyte.it)
 * Based on the "sash" project by David I. Bell
 *
 * This file is part of cbmsh, a unix-like shell for commodore computers.
 *
 * Cbmsh is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * Cbmsh is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with cbmsh.  If not, see <http://www.gnu.org/licenses/>.
 */


#ifndef	CBMSH_H
#define	CBMSH_H

#include <stdio.h>
#include <stdlib.h>
#include <unistd.h>
#include <fcntl.h>
#include <string.h>

#define	PATH_LEN	64 //1024
#define	CMD_LEN		192 //10240
#define	ALIAS_ALLOC	10 //20
#define	EXPAND_ALLOC	128 //1024
//#define	MAX_SOURCE	4 //10
#define	BUF_SIZE	112 //8192

#if defined(__C128__)
#define KEYBUF_ADDR 842
#define KEYBUF_NUMB 208
#else
#define KEYBUF_ADDR 631
#define KEYBUF_NUMB 198
#endif

#define	isBlank(ch)	(((ch) == ' ') || ((ch) == '\t') || ((ch) == '\r'))
#define	isDecimal(ch)	(((ch) >= '0') && ((ch) <= '9'))
#define	isOctal(ch)	(((ch) >= '0') && ((ch) <= '7'))
#define	isWildCard(ch)	(((ch) == '*') || ((ch) == '?') || ((ch) == '['))

#ifndef MAX
#define MAX(x, y)	((x) > (y) ? (x) : (y))
#endif
#ifndef MIN
#define MIN(x, y)	((x) < (y) ? (x) : (y))
#endif

typedef	signed char	BOOL;

#define	FALSE	((BOOL) 0)
#define	TRUE	((BOOL) 1)

#define	STR_MORE "-More-"
//extern const char *const STR_MORE = "-More-";

// Built-in command functions.
extern	void	no_ram(const char *str);
extern	char	cbm_curunit();
extern	char	cbm_command(char *cmd);
extern	char	cbm_drivetype();

#ifndef CBMSH_MINIMAL
extern	void	do_alias(int argc, const char ** argv);
extern	void	do_unalias(int argc, const char ** argv);
extern	void	do_cmp(int argc, const char ** argv);
extern	void	do_sum(int argc, const char ** argv);
#endif
extern	void	do_cd(int argc, const char ** argv);
extern	void	do_exit(int argc, const char ** argv);
extern	void	do_source(int argc, const char ** argv);
extern	void	do_help(int argc, const char ** argv);
extern	void	do_cp(int argc, const char ** argv);
extern	void	do_mv(int argc, const char ** argv);
extern	void	do_rm(int argc, const char ** argv);
extern	void	do_mkdir(int argc, const char ** argv);
extern	void	do_rmdir(int argc, const char ** argv);
extern	void	do_more(int argc, const char ** argv);
//extern	void	do_touch(int argc, const char ** argv);
extern	void	do_ls(int argc, const char ** argv);
//extern	void	do_dd(int argc, const char ** argv);
//extern	void	do_pwd(int argc, const char ** argv);
extern	void	do_echo(int argc, const char ** argv);
extern	void	do_unit(int argc, const char ** argv);
extern	void	do_clear(int argc, const char ** argv);
extern	void	do_dos(int argc, const char ** argv);
//extern	void	do_grep(int argc, const char ** argv);
//extern	void	do_file(int argc, const char ** argv);
//extern	void	do_find(int argc, const char ** argv);
//extern	void	do_ed(int argc, const char ** argv);
//extern	void	do_where(int argc, const char ** argv);

// Global utility routines.
//extern BOOL isDirectory(const char * name);
extern int nameSort(const void * p1, const void * p2);
extern char *getChunk(int size);
extern char *chunkstrdup(const char *);
extern void freeChunks(void);
extern int fullWrite(int fd, const char * buf, int len);
extern int fullRead(int fd, char * buf, int len);
extern BOOL match(const char * text, const char * pattern);

//extern	const char *buildName(const char * dirName, const char * fileName);
extern	BOOL makeArgs(const char * cmd, int * argcPtr, const char *** argvPtr);
extern	BOOL copyFile(const char * srcName, const char * destName);
extern	BOOL makeString(int argc, const char ** argv, char * buf, int bufLen);
extern	int	expandWildCards(const char * fileNamePattern, const char *** retFileTable);

// Global variable to indicate that an SIGINT occurred. This is used to stop processing.
//extern	BOOL	intFlag;
#endif
